@@ -140,7 +140,7 @@ KolabXSD::Configuration::type_type getConfigurationType(Kolab::Configuration::Co
             return KolabXSD::Configuration::type_type::relation;
         case Kolab::Configuration::TypeFileDriver:
             return KolabXSD::Configuration::type_type::file_driver;
-        default:
+        case Kolab::Configuration::Invalid:
             CRITICAL("Invalid configuration type");
     }
     return KolabXSD::Configuration::type_type::dictionary;
@@ -215,7 +215,7 @@ std::string serializeObject <Kolab::Configuration> (const Kolab::Configuration &
                 if (!relation.parent().empty()) {
                     n.parent(relation.parent());
                 }
-                if (!relation.priority() != 0) {
+                if (relation.priority() != 0) {
                     n.priority(fromInt<KolabXSD::Configuration::priority_type>(relation.priority()));
                 }
                 BOOST_FOREACH(const std::string &s, relation.members()) {
@@ -236,10 +236,10 @@ std::string serializeObject <Kolab::Configuration> (const Kolab::Configuration &
                 settings.password(fileDriver.password());
                 n.settings(settings);
             }
+            break;
+            case Kolab::Configuration::Invalid:
+                WARNING("Invalid configuration");
                 break;
-            default:
-                CRITICAL("Invalid configuration type");
-                return std::string();
         }
 
         xml_schema::namespace_infomap map;
@@ -298,10 +298,8 @@ std::string serializeObject <Kolab::Note> (const Kolab::Note &note, const std::s
             case Kolab::ClassConfidential:
                 n.classification(KolabXSD::Note::classification_type::CONFIDENTIAL);
                 break;
-            default:
-                ERROR("unknown classification");
         }
-        
+
         if (!note.attachments().empty()) {
             const std::vector<Kolab::Attachment> &l = note.attachments();
             BOOST_FOREACH(const Kolab::Attachment &a, l) {
@@ -378,10 +376,8 @@ std::string serializeObject <Kolab::File> (const Kolab::File &file, const std::s
             case Kolab::ClassConfidential:
                 n.classification(KolabXSD::File::classification_type::CONFIDENTIAL);
                 break;
-            default:
-                ERROR("unknown classification");
         }
-        
+
         n.note(file.note());
 
         if (!file.customProperties().empty()) {
@@ -449,8 +445,6 @@ boost::shared_ptr<Kolab::Note> deserializeObject <Kolab::Note> (const std::strin
                 case KolabXSD::Note::classification_type::CONFIDENTIAL:
                     n->setClassification(Kolab::ClassConfidential);
                     break;
-                default:
-                    ERROR("unknown classification");
             }
         }
 
@@ -671,8 +665,6 @@ boost::shared_ptr<Kolab::File> deserializeObject <Kolab::File> (const std::strin
                 case KolabXSD::File::classification_type::CONFIDENTIAL:
                     n->setClassification(Kolab::ClassConfidential);
                     break;
-                default:
-                    ERROR("unknown classification");
             }
         }
 
