@@ -191,7 +191,9 @@ cDateTime toDateTime(const std::string &input)
             if (input.at(15) == 'Z') {
                 isUtc = true;
             } else {
-                ERROR("wrong utc char? " + input.at(15));
+                std::ostringstream s;
+                s << "wrong utc char? " << input.at(15);
+                ERROR(s.str());
                 return cDateTime();
             }
         }
@@ -240,8 +242,6 @@ vcard_4_0::PrefTypeValueType fromCryptoPref(Kolab::Crypto::CryptoPref pref)
             return vcard_4_0::CryptoType::encryptpref_type::text_type::IfPossible;
         case Kolab::Crypto::Never:
             return vcard_4_0::CryptoType::encryptpref_type::text_type::Never;
-        default:
-            WARNING("unknown encrypt pref");
     }
     return vcard_4_0::CryptoType::encryptpref_type::text_type::Ask;
 }
@@ -257,8 +257,6 @@ Kolab::Crypto::CryptoPref toCryptoPref(vcard_4_0::PrefTypeValueType pref)
             return Kolab::Crypto::IfPossible;
         case vcard_4_0::CryptoType::encryptpref_type::text_type::Never:
             return Kolab::Crypto::Never;
-        default:
-            WARNING("unknown encrypt pref");
     }
     return Kolab::Crypto::Ask;
 }
@@ -603,7 +601,7 @@ void writeCard<Kolab::Contact>(vcard_4_0::vcard &vcard, const Kolab::Contact &co
             case Contact::Female:
                 vcard.gender(vcard::gender_type(vcard::gender_type::sex_type::F));
                 break;
-            default:
+            case Contact::NotSet:
                 ERROR("Unhandled gender");
         }
     }
@@ -746,8 +744,8 @@ void writeCard<Kolab::Contact>(vcard_4_0::vcard &vcard, const Kolab::Contact &co
                 case Kolab::Key::PKCS7_MIME:
                     keys.push_back(vcard_4_0::keyPropType(uriInlineEncoding(k.key(), MIME_PKCS7_MIME)));
                     break;
-                default:
-                    LOG("Unhandled/Invalid keytype");
+                case Kolab::Key::Invalid:
+                    LOG("Invalid keytype");
                     break;
             }
         }
