@@ -23,11 +23,9 @@
 
 #include "src/kolabformat.h"
 
-#define TESTFILEDIR "../../tests/testfiles/"
-
 void ParsingTest::vcardParsingTest()
 {
-    const Kolab::Contact &contact = Kolab::readContact(TESTFILEDIR "vcard/contact.xml", true);
+    const Kolab::Contact &contact = Kolab::readContact(TEST_DATA_PATH "/testfiles/vcard/contact.xml", true);
     QCOMPARE(Kolab::error(), Kolab::NoError);
     std::cout << Kolab::writeContact(contact);
 }
@@ -35,4 +33,4 @@ void ParsingTest::vcardParsingTest()
 
 QTEST_MAIN( ParsingTest )
 
-#include "parsingtest.moc"
\ No newline at end of file
+#include "parsingtest.moc"
